@@ -4,8 +4,8 @@ __author__ = ('Aitor Blanco-Miguez (aitor.blancomiguez@unitn.it), '
               'Nicola Segata (nicola.segata@unitn.it), '
               'Duy Tin Truong, '
               'Francesco Asnicar (f.asnicar@unitn.it)')
-__version__ = '4.0.5'
-__date__ = '23 Feb 2023'
+__version__ = '4.0.6'
+__date__ = '1 Mar 2023'
 
 import sys
 try:
